{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#bcftools-index.cwl",
            "label": "bcftools-index-1.6",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/bcftools:1.6--0"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6300
                }
            ],
            "baseCommand": [
                "bcftools",
                "index"
            ],
            "inputs": [
                {
                    "id": "#bcftools-index.cwl/bcftools-index-1.6/vcf",
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "input VCF file"
                },
                {
                    "id": "#bcftools-index.cwl/bcftools-index-1.6/nthreads",
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--threads",
                        "position": 1
                    },
                    "doc": "number of cpu cores to be used"
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "prefix": "-o",
                    "valueFrom": "$(inputs.vcf.basename).tbi"
                }
            ],
            "outputs": [
                {
                    "id": "#bcftools-index.cwl/bcftools-index-1.6/vcf_tbi",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename).tbi"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#htslib-bgzip.cwl",
            "label": "htslib-bgzip-1.9--h47928c2_5",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/htslib:1.9--h47928c2_5"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6300
                }
            ],
            "baseCommand": [
                "bgzip"
            ],
            "inputs": [
                {
                    "id": "#htslib-bgzip.cwl/htslib-bgzip-1.9--h47928c2_5/in_file",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-c",
                        "position": 1
                    },
                    "doc": "input file"
                }
            ],
            "outputs": [
                {
                    "id": "#htslib-bgzip.cwl/htslib-bgzip-1.9--h47928c2_5/gz_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).gz"
                    }
                }
            ],
            "stdout": "$(inputs.in_file.basename).gz",
            "arguments": []
        },
        {
            "class": "CommandLineTool",
            "id": "#parabricks-germline.cwl",
            "label": "parabricks-fq2bam",
            "baseCommand": [
                "/opt/pkg/parabricks/pbrun",
                "germline"
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "dbSNP data file for base recalibrator",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--knownSites"
                    },
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/dbsnp"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#parabricks-germline.cwl/parabricks-fq2bam/fqs/read1",
                                    "type": "File",
                                    "inputBinding": {
                                        "position": 1
                                    }
                                },
                                {
                                    "name": "#parabricks-germline.cwl/parabricks-fq2bam/fqs/read2",
                                    "type": "File",
                                    "inputBinding": {
                                        "position": 2
                                    }
                                }
                            ]
                        },
                        "inputBinding": {
                            "prefix": "--in-fq"
                        }
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "FastQ file from next-generation sequencers",
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/fqs"
                },
                {
                    "type": "File",
                    "doc": "Mills indel data file for base recalibrator",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--knownSites"
                    },
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/mills_indel"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--num-gpus"
                    },
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/num_gpus"
                },
                {
                    "type": "File",
                    "doc": "Onek indel data file for base recalibrator",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--knownSites"
                    },
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/onek_indel"
                },
                {
                    "type": "string",
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/outprefix"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ref"
                    },
                    "doc": "FastA file for reference genome",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).mark_dups.bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/bam"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).g.vcf"
                    },
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/gvcf"
                },
                {
                    "type": "File",
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/log",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).log"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outprefix).bqsr.recal.table"
                    },
                    "id": "#parabricks-germline.cwl/parabricks-fq2bam/recal"
                }
            ],
            "stderr": "$(inputs.outprefix).log",
            "arguments": [
                {
                    "position": 6,
                    "prefix": "--out-bam",
                    "valueFrom": "$(inputs.outprefix).mark_dups.bam"
                },
                {
                    "position": 7,
                    "prefix": "--out-variants",
                    "valueFrom": "$(inputs.outprefix).g.vcf"
                },
                {
                    "position": 8,
                    "prefix": "--out-recal-file",
                    "valueFrom": "$(inputs.outprefix).recal.table"
                },
                {
                    "position": 9,
                    "valueFrom": "--gvcf"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "germline",
            "inputs": [
                {
                    "type": "File",
                    "doc": "dbSNP data file for base recalibrator",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/dbsnp"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#main/fqs/read1",
                                    "type": "File"
                                },
                                {
                                    "name": "#main/fqs/read2",
                                    "type": "File"
                                }
                            ]
                        }
                    },
                    "doc": "FastQ file from next-generation sequencers",
                    "id": "#main/fqs"
                },
                {
                    "type": "File",
                    "doc": "Mills indel data file for base recalibrator",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/mills_indel"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/num_gpus"
                },
                {
                    "type": "File",
                    "doc": "Onek indel data file for base recalibrator",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/onek_indel"
                },
                {
                    "type": "string",
                    "id": "#main/outprefix"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "doc": "FastA file for reference genome",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#main/reference"
                }
            ],
            "steps": [
                {
                    "label": "bcftools_index",
                    "run": "#bcftools-index.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#main/bcftools_index/nthreads"
                        },
                        {
                            "source": "#main/htslib_bgzip/gz_file",
                            "id": "#main/bcftools_index/vcf"
                        }
                    ],
                    "out": [
                        "#main/bcftools_index/vcf_tbi"
                    ],
                    "id": "#main/bcftools_index"
                },
                {
                    "label": "parabricks_germline",
                    "run": "#parabricks-germline.cwl",
                    "in": [
                        {
                            "source": "#main/dbsnp",
                            "id": "#main/germline/dbsnp"
                        },
                        {
                            "source": "#main/fqs",
                            "id": "#main/germline/fqs"
                        },
                        {
                            "source": "#main/mills_indel",
                            "id": "#main/germline/mills_indel"
                        },
                        {
                            "source": "#main/num_gpus",
                            "id": "#main/germline/num_gpus"
                        },
                        {
                            "source": "#main/onek_indel",
                            "id": "#main/germline/onek_indel"
                        },
                        {
                            "source": "#main/outprefix",
                            "id": "#main/germline/outprefix"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/germline/reference"
                        }
                    ],
                    "out": [
                        "#main/germline/bam",
                        "#main/germline/recal",
                        "#main/germline/gvcf",
                        "#main/germline/log"
                    ],
                    "id": "#main/germline"
                },
                {
                    "label": "htslib_bgzip",
                    "run": "#htslib-bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/germline/gvcf",
                            "id": "#main/htslib_bgzip/in_file"
                        }
                    ],
                    "out": [
                        "#main/htslib_bgzip/gz_file"
                    ],
                    "id": "#main/htslib_bgzip"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "outputSource": "#main/germline/bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3016",
                    "outputSource": "#main/htslib_bgzip/gz_file",
                    "id": "#main/gvcf_gz"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3700",
                    "outputSource": "#main/bcftools_index/vcf_tbi",
                    "id": "#main/gvcf_tbi"
                },
                {
                    "type": "File",
                    "outputSource": "#main/germline/log",
                    "id": "#main/log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/germline/recal",
                    "id": "#main/recal"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "edam": "http://edamontology.org/"
    }
}
